\name{MultiModGraph}
\alias{MultiModGraph}
\title{Multi-Predictor Moderator Graph
}
\description{Outputs a scatterplot and boxplot faceted by the categorical moderator from a fixed or random effects moderator analysis. Used to visually depict multi-predictor moderators.
}
\usage{
MultiModGraph(meta, conmod, catmod, method = "random",

conmod.name = NULL, title = NULL)
}
\arguments{
\item{meta}{\code{data.frame} with id, g (unbiased standardized mean difference), var.g (variance of g) for comparison group)for each study. The function requires that the column name for these values be exactly as stated here.
}
  \item{conmod}{Continuous moderator variable used for analysis.
}
  \item{catmod}{Categorical moderator variable used for analysis.  
}
  \item{method}{Model used, either \code{random} or \code{fixed} effects. Default is \code{random}.
}
  \item{conmod.name}{Name of continuous moderator variable to appear on x-axis of plot. Default is NULL.
}
  \item{title}{Plot title. Default is NULL.
}
}
\value{Multivariate moderator scatterplot graph faceted by levels of categorical moderator. The size of the points are based on study precision, where larger points have smaller standard errors and are more accurate estimates of the population parameter effect size. In addition, a weighted regression line is drawn based on either a fixed or random effects analysis. The ggplot2 packages outputs the rich graphics.  
}
\references{ Cooper, H., Hedges, L.V., & Valentine, J.C. (2009). \emph{The handbook of research synthesis and meta-analysis} (2nd edition). New York: Russell Sage Foundation. 
}
\author{ AC Del Re & William T. Hoyt 
}
\examples{
id<-c(1, rep(1:19))
n.1<-c(10,20,13,22,28,12,12,36,19,12,36,75,33,121,37,14,40,16,14,20)
n.2 <- c(11,22,10,20,25,12,12,36,19,11,34,75,33,120,37,14,40,16,10,21)
g <- c(.68,.56,.23,.64,.49,-.04,1.49,1.33,.58,1.18,-.11,1.27,.26,.40,.49,
.51,.40,.34,.42,1.16)
var.g <- c(.08,.06,.03,.04,.09,.04,.009,.033,.0058,.018,.011,.027,.026,.0040,
.049,.0051,.040,.034,.0042,.016)
mod<-factor(c(rep(c(1,1,2,3),5)))
mod2 <- c(1:5, 2,2,2,2,2, 1:5, 3,2,3,2,3)
df<-data.frame(id, n.1,n.2, g, var.g,mod, mod2)

# Example

MultiModGraph(df, conmod = df$mod2, catmod = df$mod)
}
\keyword{ aplot }

